:
# disable-accounts.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.0.1 Thu Nov  5 12:32:00 PST 1998 bpowell fixed up so that
# accounts less than 100 really get set to noshell 
# version 3.0.2 Tue Dec 15 10:00:15 PST 1998 fixed a bug where blank shells
# now get set almost properly
# version 3.0.3 Mon Jan  4 17:00:30 PST 1999 bpowell/zen fix so that both
# blank shells as well as anything else in the illegal range gets set to noshell 
# version 3.0.6 Thu Feb 25 08:54:54 PST 1999 bpowell make the check and fix
# be consistent by checking/disabling everything including sys
# version 3.2.1 Thu Oct 14 08:43:35 PDT 1999 suggestion by Dieter Gobbers to
# check for noshell in the fix() area and leave it alone if its already set to 
# noshell
# version 3.2.2 bug fix for above
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0
# version 4.1/1.0 AIX-5.2 - Check for both /bin/false or noshell. Swap to /bin/false
# by default for modifications to support standard local stuff, no logging but standard shell - 
# M. Archibald - Fri Oct 24 14:28:08 PDT 2003 

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/sbin/noshell /etc/passwd /bin/false'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi


#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF
 
 $MYNAME : Ensure login shell for "system" accounts are disabled with /bin/false
 these are accounts less than 100 and greater than 60000 by default but may
 include others.  We check for both /bin/false and noshell just to make sure
 A basic listing for SysV Unix "system" level accounts is:

 bin, daemon, adm, lp, smtp, sys, uucp, nuucp, listen, nobody, noaccess

 Note: "sys" account might need to be left open since it starts accounting
	on some systems. Titan turns it off by default

 Note2: If you want something more verbose than /bin/false see the /sbin/noshell script
	we create and replace /bin/false with this.
	
	PLEASE look at $TITANDIR/src1/noshell.c A binary version of noshell is
	MUCH better than /bin/false as it provides reporting on access attempts.
        Use/replace the /sbin/noshell that this script creates with the noshell.c 
	binary after you compile then swap /sbin/noshell for /bin/false.
 
EOF

}

CreateNoShell() {

if [ -f /sbin/noshell ] ; then
                t_echo 1 "        File /sbin/noshell already exists; not changing"
                else
  t_echo 1 "         Creating /sbin/noshell"
  t_echo 1 "  You should replace this one with a binary you build from the $TITANHOME/src1 directory"
  t_echo 2 " "

cat << EOF > /sbin/noshell
:
# noshell.sh from TITAN.
#  You should replace this ASAP with the compiled version Titan,v4.0/src1/noshell.c
trap "" 1  2  3  4  5  6 7 8 9 10 12 15 19

HOSTNAME=`uname -n`
USER=\`id | awk '{print $1}' | awk -F= '{print $1}'\`
/bin/cat /dev/null | /usr/bin/mailx -s "Attempted access by ${USER} on host ${HOSTNAME}" root@${HOSTNAME} &
echo "Sorry"
wait
exit

EOF
		chmod 555 /sbin/noshell
		if [ $? -ne 0 ]
                then
                t_echo 1 " Problems creating /sbin/noshell; exiting "
                exit 1
             fi  
        fi

}

Check() {

#
# Check for /bin/false in AIX, as opposed to noshell, or along with noshell
# Get UID/Uname under UID 100 and over UID 60001
PLIST=`awk -F":" '($3 < 100) {print};($3 > 60000) {print}' /etc/passwd | egrep -v '(^root\:)' | awk -F":" '{print $1}'`
PCOUNT=`echo $PLIST | wc -w`
t_echo 2 " Checking $PCOUNT Users.... "
t_echo 2 " Checking that shell set to /bin/false or noshell for: "
t_echo 2 " "
t_echo 2 $PLIST

GCOUNT=0
BCOUNT=0

t_echo 3 " Verify shell status.... "
t_echo 2 " "
for USR in $PLIST
 do
  NOSHEL=`grep "^$USR\:" /etc/passwd | egrep '(:/sbin/noshell$|:/bin/false$)'`
  USHEL=`grep "^$USR\:" /etc/passwd | awk -F":" '{print $7}'`
  if [ -z "$NOSHEL" ]; then
   t_echo 0 "         $USR shell = $USHEL - FAILS CHECK"
   BCOUNT=`expr $BCOUNT + 1`
  else
   t_echo 1 " $USR shell secure = $USHEL - PASSES CHECK"
   GCOUNT=`expr $GCOUNT + 1`
  fi
done

t_echo 2 " "

  if [ $GCOUNT -lt $PCOUNT ]; then
 t_echo 2 " $BCOUNT Users Not Secured Out Of $PCOUNT"
  fi

  if [ $GCOUNT -eq $PCOUNT ]; then
 t_echo 1 "         All User Accounts PASS CHECK"
	exit 1
  fi
	

}

Fix() {

t_echo 2 " Setting shell to noshell for: "

# Get UID/Uname under UID 100 and over UID 60001
PLIST=`awk -F":" '($3 < 100) {print};($3 > 60000) {print}' /etc/passwd | egrep -v '(^root\:|:/sbin/noshell$|:/bin/false$)' | awk -F":" '{print $1}'`

t_echo 2 " "
t_echo 2 "$PLIST"
t_echo 2 " "

for USER in $PLIST
 do
 t_echo 1 "        $USER login not disabled. REPAIRING"

# Replace below /bin/false edit entry if you want noshell support
#
# g/^$USER:/s/:[^:]*$/:\/sbin\/noshell/g
#

ed - /etc/passwd << EOEF
g/^$USER:/s/:[^:]*$/:\/bin\/false/g
.
w
q
EOEF
 t_echo 1 "         $USER shell now = /bin/false - PASSES CHECK"
done
 
}

action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	CreateNoShell
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
	t_echo 1 "         ERROR:Invalid arg $action"
	t_echo 1 "         ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
	t_echo 1 " "
	;;
	esac
# finis

