:
# defpwparams.sh
# version 3.1.4 Sep 13 11:21:02 PDT 1999
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module donated by Mitko Stoyanov, August 1999
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/passwd'
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
OS=`uname -r`

#BEGIN CONFIURABLE STUFF

# File(s) that will be modified
PWDEFFILE="/etc/default/passwd"
 
# Minimum time period before the password can be changed. 
PWMIN=1

# Maximum time period that password is valid
PWMAX=13

# The number of days relative to MAX before the password expires to 
# start warning the user of the required change
PWWARN=4

# the following requires that all passwords must have minimum length of 6
PWLEN=6

#END CONFIGURABLE STUFF

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh
 
Intro() {
cat << EOF_INTRO
$MYNAME : This script checks/modifies the /etc/default/passwd file for 
the default parameters It is recommended that you modify the $MYNAME script to
match YOUR Site Security Policy. Titan without modification will change
the values to this:
 
# Minimum time period (weeks) before the password can be changed.
PWMIN=1
 
# Maximum time period (weeks) that password is valid
PWMAX=13

# The number of days relative to password expiration to
# start warning the user of the required change
PWWARN=4 
 
# Minimum length required for all passwords 
PWLEN=6  
 

EOF_INTRO
}

Check() {

# there must be exactly ONE matching entry or we complain

   if [ -r "$PWDEFFILE" ];then 
   if [ "`grep -cs \"^MINWEEKS=${PWMIN}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*MINWEEKS=\" $PWDEFFILE`" -eq 1 ];then 
       t_echo 1 "   passwd MINWEEKS - PASSES CHECK "
   else
      t_echo 0 "  passwd MINWEEKS - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^MAXWEEKS=${PWMAX}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*MAXWEEKS=\" $PWDEFFILE`" -eq 1 ];then 
       t_echo 1 "   passwd MAXWEEKS - PASSES CHECK "
   else
      t_echo 0 "  passwd MAXWEEKS - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^WARNWEEKS=${PWWARN}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*WARNWEEKS=\" $PWDEFFILE`" -eq 1 ];then 
       t_echo 1 "   passwd WARNWEEKS - PASSES CHECK "
   else
      t_echo 0 "  passwd WARNWEEKS - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^PASSLENGTH=${PWLEN}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*PASSLENGTH=\" $PWDEFFILE`" -eq 1 ];then 
       t_echo 1 "   passwd PASSLENGTH - PASSES CHECK "
   else
      t_echo 0 "  passwd PASSLENGTH - FAILS CHECK" 
   fi
  else 
      t_echo 0 "  passwd $PWDEFFILE missing - FAILS CHECK" 
  fi


}


Fix() {

   if [ -r "$PWDEFFILE" ] && \
      [ "`grep -cs \"^MINWEEKS=${PWMIN}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*MINWEEKS=\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^MAXWEEKS=${PWMAX}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*MAXWEEKS=\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^WARNWEEKS=${PWWARN}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*WARNWEEKS=\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^PASSLENGTH=${PWLEN}\" $PWDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*PASSLENGTH=\" $PWDEFFILE`" -eq 1 ];then 
       t_echo 1 "   $PWDEFFILE entries - PASSES CHECK "
   else
      t_echo 0 "  $PWDEFFILE entries - FAILS CHECK" 
      t_echo 2 "  Fixing "$PWDEFFILE" now...." 
        if [ ! -f "$PWDEFFILE" ];then
            touch "$PWDEFFILE" && chmod 444 "$PWDEFFILE" \
            && chown root "$PWDEFFILE" &&  chgrp sys "$PWDEFFILE"
        else
             cp -p "$PWDEFFILE" "$PWDEFFILE".${RUNDATE}
        fi
	ed - "$PWDEFFILE" <<- __INPUT__ 
	g/^[^#]*MINWEEKS=/d
	g/^[^#]*MAXWEEKS=/d
	g/^[^#]*WARNWEEKS=/d
	g/^[^#]*PASSLENGTH=/d
	a
	# Added by Titan $MYNAME on $RUNDATE
	.
	a
	MINWEEKS=${PWMIN}
	.
	a
	MAXWEEKS=${PWMAX}
	.
	a
	WARNWEEKS=${PWWARN}
	.
	a
	PASSLENGTH=${PWLEN}
	.
	w
	q
	__INPUT__
      if [ "$?" -ne 0 ];then
        t_echo 1 "  Fixing "$PWDEFFILE" ERROR - check the file" 
        exit 1
      fi
   fi


}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
;;
esac

