:
# hostallow.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 4.0 beta4 June 16, 2002

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/hosts.allow /etc/hosts.deny'
HOST=`uname -n`

# Modify the next variable adding in each host or network you want to allow remote
# access from seperated by a a whitespace
ALLOWHOSTS=" "

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh


case "`uname -r`" in
5.[9]*) ;;
*)
        t_echo 1 "$MYNAME ERROR - This script is Only supported on Solaris 2.9 and newer"
        exit 1;;
esac

Intro() {

cat << EOF

 $MYNAME - This program takes advantage of Solaris 9 inclusion of libwrap in
the ssh daemon (/usr/lib/ssh/sshd) .$MYNAME first looks looks to see if 
/usr/sfw/lib/libwrap.so.1 is installed then checks if /etc/hosts.allow and
/etc/hosts.deny exists. If run in verify mode, it just verifies that they exist
and are not zero length.

If run in fix mode, it creates them and sets hosts.allow to only allow connections
from the local sub-net. This behaviour may not be what you want, and /etc/hosts.allow
should be further restricted to just the hosts that you allow access from. Titan
provides a variable "ALLOWHOSTS" which you can add in the hosts you want added to
/etc/hosts.allow.


EOF

}

Fix() {

	if  [ -s /etc/hosts.allow -a -s /etc/hosts.deny ]; then
       	t_echo 0 "/etc/hosts.allow and /etc/hosts.deny exists"
	t_echo 0 " and are not empty - Cannot Proceed"
 exit 1 
fi

# Create /etc/hosts.allow

	if  [ ! -f /etc/hosts.allow -o -z /etc/hosts.allow ]; then
	t_echo 3 " /etc/hosts.allow does not exist or is empty creating..."

	cat << EOF_ALLOW > /etc/hosts.allow
# Configuration file for hosts.allow.  See hosts_access(5).
#
ALL: LOCAL

EOF_ALLOW

	chmod 644 /etc/hosts.allow
	fi

# Create /etc/hosts.deny
 
	if  [ ! -f /etc/hosts.deny -o -z /etc/hosts.deny ]; then
	t_echo 3 " /etc/hosts.deny does not exist  or is empty creating..."

	cat << EOF_DENY > /etc/hosts.deny
# Configuration file for hosts.deny.  See hosts_access(5).
#
ALL: ALL
 
EOF_DENY
 
	chmod 644 /etc/hosts.deny
	fi

}


Check() {

if  [ -f /usr/sfw/lib/libwrap.so.1 -a -s /etc/hosts.allow -a -s /etc/hosts.deny ]; then
      t_echo 0 " /etc/hosts.allow and /etc/hosts.deny exists and are not empty - PASSES CHECK"

else
        t_echo 1 "       No /etc/hosts.allow or /etc/hosts.deny -  FAILS CHECK"
	exit 1
fi

}


action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
	Check
        ;;
        *)
        t_echo 1 "       ERROR:Invalid arg $action"
        t_echo 1 "       ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac
