/*****************************************************************************
* Module : testntoa
* Summary : To test if the inet_ntoa subroutine of the inet family works 
*	    properly.  Due to the byte ordering of different systems, the
*	    function does not always work as advertised.
*	    The function also tests to see if the str_ia macro works on the system.
*	    The str_ia macro is a substitute for a broken inet_ntoa function.
* Input Args: None.
* Results   : Will print one of two messages, depending on if the function
*	      is broken or not.
* Assumptions : The program assumes that "sun408" is in the /etc/hosts file and
		the internet address is "129.99.32.145".
* Author:
*              Michele D. Crabb
*              Computer Sciences Corporation
*              NASA Ames Research Center
*              Mail Stop 258-6
*              Moffett Field, CA 94035
*              (415) 604 - 4337
*              crabb@amelia.nas.nasa.gov
*******************************************************************************/
#include <stdio.h>
#include <netdb.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

/* Comment this out on a non SGI IRIS system */
/* #define SGI_IRIS /* */


#define str_ia(addrp)   sprintf("xxx.xxx.xxx.xxx", "%d.%d.%d.%d",addrp[0]&0xff, addrp[1]&0xff, addrp[2]&0xff, addrp[3]&0xff)

main()

{
	char *host = "sun439.nas.nasa.gov";
	char *haddr = "129.99.34.48";
	struct hostent *hentry;
	struct in_addr inaddr;
	u_long addr = 0;
	char *taddr,*iaddr;

	 if ( (hentry = gethostbyname(host)) != NULL ) {
		inaddr.s_addr = *(unsigned long *)hentry->h_addr_list[0];
		taddr = (char *)inet_ntoa(inaddr);
		if (strcmp(haddr,taddr) != 0 )
			(void) printf("The inet_ntoa function is broken.\n");
		else
			(void) printf("The inet_ntoa function works!\n");
		
#ifdef SGI_IRIS
	printf("The macro does not work.\n");
#else
		/* Now see if the macro works */
		iaddr = (char *)hentry->h_addr_list[0];
		if ( strcmp(haddr,str_ia(iaddr) ) != 0)
			(void) printf("The str_ia macro does not work.\n");
		else
			(void) printf("The str_ia macro works!\n");
#endif
	}
	else
		(void) printf("could not get hostentry for %s\n",host);

}

